This crate contains kube-rs compatible bindings for Kubernetes custom resources for the jobset.x-k8s.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
jobset.x-k8s.io/v1alpha2
JobSet